#############
# In both experiments, we asked participants to fill out the igroup presence questionnaire (IPQ)
# after completing the experiment. The questionnaire and the reference data can be obtained at:
# http://www.igroup.org/pq/ipq/index.php
# The items can be aggregated into three scales: Spatial presence, involvement, and realism.
# The data provided here consists of the respective scores of all participants on these scales,
# we used unpaired t-Tests to compare those values to the reference data.
# While the results regarding involvement and realism compare well to the reference data, the
# spatial presence is higher (significantly larger in Exp. 2, margnially significant in Exp. 1).
# These results fit with our results from other studies using similar setups (Leap + Oculus), were
# we observed an increased spatial presence. Seeing that the setups used for the reference data
# did not include real-time motion capture, this seems to be the reason for the differences in the
# spatial presence scores.

# set the path to directory containing the data
setwd("C:\\Users\\Animazoo\\Documents\\misc\\091116_CrossmodalCongruencyLeitfaden\\140518_CMCinVR\\questionnaire")
# read data
data_ref      <- read.table("reference_ipq.txt", header = TRUE)
data_obs_exp1 <- read.table("observed_ipq_exp1.txt", header = TRUE)
data_obs_exp2 <- read.table("observed_ipq_exp2.txt", header = TRUE)
# we use an unpaired test here
# Data from Exp. 1
t1 <- t.test(data_ref$SpatialPresenceRef,
             data_obs_exp1$SpatialPresence, paired = FALSE, alternative = 'less')
t2 <- t.test(data_ref$InvolvementRef,
             data_obs_exp1$Involvement, paired = FALSE, alternative = 'less')
t3 <- t.test(data_ref$RealismRef,
             data_obs_exp1$Realism, paired = FALSE, alternative = 'less')
			 
format(p.adjust(c(t1$p.value, t2$p.value, t3$p.value), method = "bonf"), scientific = FALSE)
format(c(t1$parameter, t2$parameter, t3$parameter), scientific = FALSE)
format(c(t1$statistic, t2$statistic, t3$statistic), scientific = FALSE)
format(c(t1$p.value, t2$p.value, t3$p.value), scientific = FALSE)

# Data from Exp. 2
t1 <- t.test(data_ref$SpatialPresenceRef,
             data_obs_exp2$SpatialPresence, paired = FALSE, alternative = 'less')
t2 <- t.test(data_ref$InvolvementRef,
             data_obs_exp2$Involvement, paired = FALSE, alternative = 'less')
t3 <- t.test(data_ref$RealismRef,
             data_obs_exp2$Realism, paired = FALSE, alternative = 'less')

format(p.adjust(c(t1$p.value, t2$p.value, t3$p.value), method = "bonf"), scientific = FALSE)
format(c(t1$parameter, t2$parameter, t3$parameter), scientific = FALSE)
format(c(t1$statistic, t2$statistic, t3$statistic), scientific = FALSE)
format(c(t1$p.value, t2$p.value, t3$p.value), scientific = FALSE)

# Comparison between the experiments
t1 <- t.test(data_obs_exp1$SpatialPresence,
             data_obs_exp2$SpatialPresence, paired = FALSE, alternative = 'less')
t2 <- t.test(data_obs_exp1$Involvement,
             data_obs_exp2$Involvement, paired = FALSE, alternative = 'less')
t3 <- t.test(data_obs_exp1$Realism,
             data_obs_exp2$Realism, paired = FALSE, alternative = 'less')

format(p.adjust(c(t1$p.value, t2$p.value, t3$p.value), method = "bonf"), scientific = FALSE)
format(c(t1$parameter, t2$parameter, t3$parameter), scientific = FALSE)
format(c(t1$statistic, t2$statistic, t3$statistic), scientific = FALSE)
format(c(t1$p.value, t2$p.value, t3$p.value), scientific = FALSE)